.. _topics-commands:

=================
命令行工具
=================

Moose 提供了一系列的基于命令行的工具，以方便开发人员快速地创建和控制 ``Moose`` 项目。其中，有一些命令是全局的，可以在系统中任何地方被调用；另一些类似于子命令的形式，需要作为工具的参数被调用，也是我们与Moose交互的主要方式。

为了区分两者，我们称前者为Moose工具（Tools），后者为Moose命令（commands）。下面两节分别列出了两者，并对它们的作用和参数进行了解释。

.. _topics-moose-tools:

Moose工具
==================

输入::

    moose-admin startproject myproject [project_dir]

会在 ``project_dir`` 创建一个Moose项目,

.. _topics-moose-commands:

Moose命令
==================
